==> haskell-vector-th-unbox-0.2.1.9-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-th-unbox
version:              0.2.1.9
visibility:           public
id:                   vector-th-unbox-0.2.1.9-HLpcDjWMI4Z8izcRdNtNGs
key:                  vector-th-unbox-0.2.1.9-HLpcDjWMI4Z8izcRdNtNGs
license:              BSD-3-Clause
copyright:            (c) 2012-2015 Liyang HU
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Liyang HU <vector-th-unbox@liyang.hu>
stability:            experimental
homepage:             https://github.com/tsurucapital/vector-th-unbox
synopsis:             Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.

    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.

category:             Data
abi:                  f1ab58833f94cead38b3d1b9968b7398
exposed:              True
exposed-modules:      Data.Vector.Unboxed.Deriving
import-dirs:          /usr/lib/ghc-9.0.1/site-local/vector-th-unbox-0.2.1.9
library-dirs:         /usr/lib/ghc-9.0.1/site-local/vector-th-unbox-0.2.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/vector-th-unbox-0.2.1.9
hs-libraries:         HSvector-th-unbox-0.2.1.9-HLpcDjWMI4Z8izcRdNtNGs
depends:
    base-4.15.0.0 template-haskell-2.17.0.0
    vector-0.12.3.0-Ds1jjFyjexp9iWlYSOgIe8

haddock-interfaces:
    /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock

haddock-html:         /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-th-unbox-0.2.1.9-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-th-unbox
version:              0.2.1.9
visibility:           public
id:                   vector-th-unbox-0.2.1.9-5ExRRMHUy6mFdpOVh6xyi9
key:                  vector-th-unbox-0.2.1.9-5ExRRMHUy6mFdpOVh6xyi9
license:              BSD-3-Clause
copyright:            (c) 2012-2015 Liyang HU
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Liyang HU <vector-th-unbox@liyang.hu>
stability:            experimental
homepage:             https://github.com/tsurucapital/vector-th-unbox
synopsis:             Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.

    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.

category:             Data
abi:                  2bd332c4a81c21a9f07fa56ecba2baab
exposed:              True
exposed-modules:      Data.Vector.Unboxed.Deriving
import-dirs:          /usr/lib/ghc-9.0.1/site-local/vector-th-unbox-0.2.1.9
library-dirs:         /usr/lib/ghc-9.0.1/site-local/vector-th-unbox-0.2.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/vector-th-unbox-0.2.1.9
hs-libraries:         HSvector-th-unbox-0.2.1.9-5ExRRMHUy6mFdpOVh6xyi9
depends:
    base-4.15.0.0 template-haskell-2.17.0.0
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG

haddock-interfaces:
    /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock

haddock-html:         /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
